@@ -29,6 +29,12 @@ class ScreenshotPortal : public QDBusAbstractAdaptor
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.freedesktop.impl.portal.Screenshot")
 public:
+    struct ColorRGB {
+        double red;
+        double green;
+        double blue;
+    };
+
     explicit ScreenshotPortal(QObject *parent);
     ~ScreenshotPortal();
 
@@ -38,6 +44,12 @@ public Q_SLOTS:
                     const QString &parent_window,
                     const QVariantMap &options,
                     QVariantMap &results);
+
+    uint PickColor(const QDBusObjectPath &handle,
+                   const QString &app_id,
+                   const QString &parent_window,
+                   const QVariantMap &options,
+                   QVariantMap &results);
 };
 
 #endif // XDG_DESKTOP_PORTAL_KDE_SCREENSHOT_H
